Test coverage report: calendarium.constants

# calendarium.constants: 5 total statements, 100.0% covered

Generated: Thu 2013-05-02 12:21 SGT

Source file: /Users/martin/Repos/django-calendarium/calendarium/constants.py

Stats: 4 executed, 0 missed, 1 excluded, 26 ignored

1. `"""Constants for the ``calendarium`` app."""`
2. `from django.utils.translation import ugettext_lazy as _`
3. ``
4. ``
5. `FREQUENCIES = {`
6. `'YEARLY': 'YEARLY',`
7. `'MONTHLY': 'MONTHLY',`
8. `'WEEKLY': 'WEEKLY',`
9. `'DAILY': 'DAILY',`
10. `}`
11. ``
12. ``
13. `FREQUENCY_CHOICES = (`
14. `(FREQUENCIES['YEARLY'], _('Yearly')),`
15. `(FREQUENCIES['MONTHLY'], _('Monthly')),`
16. `(FREQUENCIES['WEEKLY'], _('Weekly')),`
17. `(FREQUENCIES['DAILY'], _('Daily')),`
18. `)`
19. ``
20. ``
21. `OCCURRENCE_DECISIONS = {`
22. `'all': 'all',`
23. `'following': 'following',`
24. `'this one': 'this one',`
25. `}`
26. ``
27. `OCCURRENCE_DECISION_CHOICESS = (`
28. `(OCCURRENCE_DECISIONS['all'], _('all')),`
29. `(OCCURRENCE_DECISIONS['following'], _('following')),`
30. `(OCCURRENCE_DECISIONS['this one'], _('this one')),`
31. `)`